#include <stdio.h>
#include <stdlib.h>
#include <X11/Xlib.h>

void die(const char *errstr) {
    fputs(errstr, stderr);
    exit(EXIT_FAILURE);
}

int main(int argc, char *argv[]) {
    char *color_hex = NULL;
    int screen;
    Display *display;
    Window root;
    Colormap colormap;
    XColor color;

    // Grab the hex color from user input
    color_hex = argv[1];
    if (!color_hex) {
        die("Usage: bgc \"#FEED29\"\n");
    }

    // Open a connection to the X server, using the
    // display specified in the DISPLAY environment variable
    display = XOpenDisplay(NULL);
    if (!display) {
        die("Falied to connect to an X Server");
    }

    // This functions are just macros to retrieve values
    screen = DefaultScreen(display);
    colormap = DefaultColormap(display, screen);
    root = RootWindow(display, screen);

    if (XParseColor(display, colormap, color_hex, &color) == 0) {
        die("Failed to parse the input into a color");
    };

    if (XAllocColor(display, colormap, &color) == 0) {
        die("Failed to allocate the color");
    }

    if (XSetWindowBackground(display, root, color.pixel) == BadGC) {
        die("Failed to set the background");
    }

    // Redraw the window with the new background
    XClearWindow(display, root);

    // Disconnect to X server
    XCloseDisplay(display);
    return EXIT_SUCCESS;
}
